// Función para restaurar el div #resto-pantalla a su forma original
function restaurarFormaOriginal() {
    d3.select("#resto-pantalla")
        .style("display", "flex") // Vuelve al diseño original
        .style("flex-direction", "row") // Configuración predeterminada de flexbox
        .selectAll(".sector")
        .remove(); // Elimina todos los sectores dentro del div
}

// Nueva función: datosTemporada (antes dividirEnSectores)
function datosTemporada() {
    const restoPantalla = d3.select("#resto-pantalla");

    // Limpia cualquier contenido previo
    restoPantalla.selectAll("*").remove();

    // Configuración de cuadrícula
    restoPantalla
        .style("display", "grid") // Cambia a diseño de cuadrícula
        .style("grid-template-columns", "1fr 1fr") // Dos columnas iguales
        .style("grid-template-rows", "1fr 1fr") // Dos filas iguales
        .style("gap", "0"); // Sin espacio entre sectores

    // Datos para los cuatro sectores con títulos
    const data = [
        { title: "Victorias/Derrotas", content: "" },
        { title: "Número total de puntos", content: "" },
        { title: "Posición Final", content: "" },
        { title: "Porcentaje de tiro", content: "" },
    ];

    // Crear los sectores con títulos
    restoPantalla
        .selectAll(".sector")
        .data(data)
        .enter()
        .append("div")
        .attr("class", "sector") // Clase para estilos en CSS
        .style("border", "1px solid black") // Opcional, para mejor visualización
        .style("background-color", "#4FC3F7") // Color de fondo
        .style("display", "flex") // Centra el contenido del sector
        .style("flex-direction", "column") // Alineación en columna para título y contenido
        .style("align-items", "flex-start") // Alineación horizontal del título a la izquierda
        .style("justify-content", "flex-start") // Alineación vertical al principio
        .style("padding", "10px") // Espaciado interno
        .each(function (d) {
            // Agregar título en la parte superior izquierda
            d3.select(this)
                .append("div")
                .attr("class", "sector-title")
                .style("font-weight", "bold")
                .style("font-size", "1.2em")
                .style("margin-bottom", "10px")
                .text(d.title);

            // Espacio reservado para contenido adicional (puedes agregar contenido dinámico aquí)
            d3.select(this)
                .append("div")
                .attr("class", "sector-content")
                .style("flex", "1") // Ocupa el resto del espacio
                .text(d.content);
        });
}


// Función para mostrar la estructura de rendimiento de jugadores
function rendimientoJugadores() {
    const restoPantalla = d3.select("#resto-pantalla");

    // Limpia cualquier contenido previo
    restoPantalla.selectAll("*").remove();

    // Crear div a la izquierda (de arriba a abajo)
    restoPantalla
        .append("div")
        .attr("id", "lado-izquierdo");

    // Crear div a la derecha (resto del espacio)
    restoPantalla
    .append("div")
    .attr("id", "lado-derecho")
    .style("flex", "1")
    .style("background-color", "#F5F5F5") // Fondo gris claro
    .style("display", "flex")
    .style("align-items", "center")
    .style("justify-content", "center")
    .style("position", "relative"); // Permite po
    crearGraficoRadar("#lado-derecho");
}

// Función para crear el gráfico de radar con etiquetas ajustadas
function crearGraficoRadar(containerSelector) {
    const container = d3.select(containerSelector);

    // Obtener las dimensiones del contenedor dinámicamente
    const boundingRect = container.node().getBoundingClientRect();
    const width = boundingRect.width; // Ancho del contenedor
    const height = boundingRect.height; // Alto del contenedor
    const margin = 50; // Margen para evitar etiquetas fuera del área visible

    // Configuración del radar
    const metrics = 8; // Número de vértices
    const levels = 5; // Número de niveles (anillos intermedios)
    const radius = (Math.min(width, height) - margin * 2) / 2 * 0.70; // Reducir tamaño del gráfico al 85%
    const angleSlice = (2 * Math.PI) / metrics;

    // Etiquetas para los vértices
    const labels = [
        "Puntos/Partido",
        "% Tiro de 2",
        "% Tiro de 3",
        "% Tiro Libre",
        "Rebotes/Partido",
        "Recuperaciones/Partido",
        "Asistencias/Partido",
        "Minutos/Partido",
    ];

    // Escala para los niveles (líneas intermedias)
    const rScale = d3.scaleLinear().range([0, radius]).domain([0, 100]);

    // Crear el SVG dentro del contenedor
    const svg = container
        .append("svg")
        .attr("width", "100%") // Ajustar el ancho al contenedor
        .attr("height", "100%") // Ajustar el alto al contenedor
        .append("g")
        .attr("transform", `translate(${width / 2}, ${height / 2})`);

    // Dibujar líneas intermedias y exteriores
    for (let level = 1; level <= levels; level++) {
        const levelRadius = (level / levels) * radius;

        const vertices = [];
        for (let i = 0; i < metrics; i++) {
            vertices.push([
                levelRadius * Math.cos(angleSlice * i - Math.PI / 2),
                levelRadius * Math.sin(angleSlice * i - Math.PI / 2),
            ]);
        }

        // Dibujar las líneas entre los vértices de cada nivel (incluyendo la exterior)
        for (let i = 0; i < vertices.length; i++) {
            const [x1, y1] = vertices[i];
            const [x2, y2] = vertices[(i + 1) % vertices.length];
            svg.append("line")
                .attr("x1", x1)
                .attr("y1", y1)
                .attr("x2", x2)
                .attr("y2", y2)
                .style("stroke", level === levels ? "#0288D1" : "#999") // Exterior en azul, intermedias en gris
                .style("stroke-width", level === levels ? 2 : 1); // Exterior más gruesa
        }
    }

    // Dibujar líneas radiales desde el centro hasta los vértices
    const exteriorVertices = [];
    for (let i = 0; i < metrics; i++) {
        const x = radius * Math.cos(angleSlice * i - Math.PI / 2);
        const y = radius * Math.sin(angleSlice * i - Math.PI / 2);
        exteriorVertices.push([x, y]);

        // Dibujar la línea radial
        svg.append("line")
            .attr("x1", 0)
            .attr("y1", 0)
            .attr("x2", x)
            .attr("y2", y)
            .style("stroke", "#444") // Líneas radiales en gris oscuro
            .style("stroke-width", 1.5); // Grosor de las líneas radiales

        // Agregar etiqueta en cada vértice exterior
        const offset = 1.15; // Desplazamiento reducido para acercar las etiquetas al gráfico
        const anchor = i === 0 || i === 4 ? "middle" : x > 0 ? "start" : "end"; // Centrado para "Puntos/Partido" y "Rebotes/Partido"
        const dy = i === 0 ? "-0.5em" : i === 4 ? "0.9em" : "0.35em"; // Ajuste vertical

        svg.append("text")
            .attr("x", x * offset) // Desplazar un poco hacia afuera
            .attr("y", y * offset) // Desplazar un poco hacia afuera
            .attr("dy", dy) // Ajustar posición vertical
            .style("text-anchor", anchor) // Alinear texto
            .style("font-size", "14px") // Tamaño más grande para mayor visibilidad
            .style("font-weight", "bold")
            .style("fill", "#333") // Color del texto
            .text(labels[i]);
    }
}
// Función para cargar datos del CSV desde una URL
function cargarJugadoresDesdeArchivo() {
    const csvPath = "assets/estadisticasRendimientoJugadores.csv"; // Ruta del archivo CSV
    const ladoIzquierdo = d3.select("#lado-izquierdo");

    // Limpia cualquier contenido previo
    ladoIzquierdo.selectAll("*").remove();

    // Configuración del contenedor
    ladoIzquierdo
        .style("display", "flex")
        .style("flex-direction", "column")
        .style("justify-content", "space-between"); // Distribución uniforme

    // Cargar el archivo CSV
    d3.csv(csvPath).then((data) => {
        // Crear un rectángulo por cada jugador
        ladoIzquierdo
            .selectAll(".jugador-rect")
            .data(data)
            .enter()
            .append("div")
            .attr("class", "jugador-rect") // Clase para estilos en CSS
            .style("flex", "1") // Hace que cada rectángulo crezca de forma uniforme
            .style("margin", "2px 0") // Espaciado mínimo entre los rectángulos
            .style("padding", "10px") // Espaciado interno
            .style("background-color", "#FFC107") // Color de fondo
            .style("color", "#000") // Color de texto
            .style("display", "flex") // Para alinear el contenido
            .style("align-items", "center") // Centrar contenido verticalmente
            .style("justify-content", "space-between") // Espacio entre los elementos
            .each(function (d) {
                // Mostrar el número del jugador en el lado izquierdo
                d3.select(this)
                    .append("div")
                    .attr("class", "jugador-numero")
                    .style("font-weight", "bold")
                    .style("font-size", "1.2em")
                    .style("flex", "0 0 auto") // Mantiene el número fijo en la izquierda
                    .style("text-align", "left")
                    .text(`${d.Nº}º`);

                // Mostrar el nombre del jugador
                d3.select(this)
                    .append("div")
                    .attr("class", "jugador-nombre")
                    .style("font-size", "1.2em")
                    .style("text-align", "center")
                    .style("flex", "1") // Permite que el nombre ocupe el resto del espacio
                    .text(d.Nombre);

                // Añadir un checkbox a la derecha
                d3.select(this)
                    .append("input")
                    .attr("type", "checkbox")
                    .attr("class", "jugador-checkbox") // Clase para aplicar estilos
                    .style("flex", "0 0 auto") // No permite que se expanda
                    .style("width", "20px") // Ancho del checkbox
                    .style("height", "20px") // Alto del checkbox
                    .style("border-radius", "50%") // Hace que sea circular
                    .style("cursor", "pointer"); // Cambia el cursor a pointer
            });
    });
}


// Evento para el click en el div superior
d3.select("#div-superior").on("click", () => {
    restaurarFormaOriginal(); // Asegúrate de empezar desde la forma original
    datosTemporada(); // Divide en sectores y añade títulos
});

// Evento para el click en el div inferior
d3.select("#div-inferior").on("click", () => {
    restaurarFormaOriginal(); // Vuelve a la forma original
    rendimientoJugadores(); // Estructura para rendimiento de jugadores
    cargarJugadoresDesdeArchivo(); // Carga y muestra los datos desde el archivo CSV
});
